README
======
Description
-----------
L'objectif de l'application est de jouer
au Sudoku. L'application fonctionne en
mode texte. Il faut fournir une grille
à résoudre sous forme de fichier.

Installation
------------
1. Télécharger le TARBALL sudokujf.tar.gz
2. Détarrer, lire le README (ce fichier)
3. On se déplace dans le répertoire créé

Utilisation
-----------
L'utilisation du programme est simple:
python3 -m sudokujf une_grille

Un fichier "Grille" est fait de 9 lignes
Exemple d'une ligne: 065020007

Documentation
-------------
Une documentation plus complête est disponible
dans le répertoire /doc

Auteur / Collaborateurs
-----------------------
Jean-François BOUCHAUDY, jfbouch@wanadoo.fr
Pseudo ;-)  Paul Hochon (git config --list)

License
-------
License MIT

Collaboration / Forker
----------------------
Cloner le projet:
$ git clone http://serveur/GIT/sudokujf.git

